@@ -81,9 +81,9 @@
  */
 
 #define VERSION		"2.5"			/* Version number... */
-#define VERS_DATE	"January 11, 2000"		/* for elm -v option */
+#define VERS_DATE	"December 15, 2000"		/* for elm -v option */
 #define WHAT_STRING	\
-	"@(#) Version 2.5, USENET supported version PL3"
+	"@(#) Version 2.5, USENET supported version PL4"
 
 #include <sys/types.h>	/* for fundamental types */
 #include <stdio.h>	/* Must get the _IOEOF flag for feof() on Convex */
