@@ -654,7 +654,7 @@ int num_to_delete;
 	      if (num_aliases = parse_aliases(line_in_file, rest_of_line)) {
 	        for (i=0; i < num_to_delete && num_aliases; i++) {
 	          if ( ((s = strstr(line_in_file, name[i])) == line_in_file) ||
-		       ((s != NULL) && (*(s-1) == ',') != NULL) ) {
+		       ((s != NULL) && (*(s-1) == ',')) ) {
 /*
  *	Collapse the to be deleted alias out of line_in_file
  */
