@@ -64,12 +64,11 @@ char *argv[], *to_whom;
 	opmode = OPMODE_READ;
 	sendmail_verbose = FALSE;
         TreatAsSpooled = FALSE;
-        appendUname = FALSE;
 	to_whom[0] = '\0';
 	batch_subject = NULL;
 	included_file = NULL;
 
-        while ((i = getopt(argc, argv, "?acd:f:hi:kKMmSs:tVvz")) != EOF) {
+        while ((i = getopt(argc, argv, "?acd:f:hi:kKMmr:Ss:tVvz")) != EOF) {
 	   switch (i) {
 	     case 'a' : arrow_cursor = TRUE;			break;
 	     case 'c' : fprintf(stderr, catgets(elm_msg_cat, ElmSet,
@@ -89,7 +88,8 @@ char *argv[], *to_whom;
 	     case 'K' : hp_softkeys = TRUE;			break;
              case 'M' : TreatAsSpooled = TRUE;			break;
 	     case 'm' : mini_menu = FALSE;			break;
-	     case 'S' : opmode = OPMODE_SEND;			break;
+ 	      case 'r' :  setelmrcName(optarg);break;
+ 	     case 'S' : opmode = OPMODE_SEND;			break;
 	     case 's' : batch_subject = optarg;
 	     	        opmode = OPMODE_SEND;
 	     	        break;
