@@ -189,7 +189,9 @@ read_rc_file()
 	}
 
 	/* Look for the elmrc file */
-	sprintf(filename, "%s/%s", user_home, elmrcfile);
+/*	sprintf(filename, "%s/%s", user_home, elmrcfile); */
+        getelmrcName(filename,SLEN);
+   
 	if ((file = fopen(filename, "r")) == NULL) {
 	  dprint(2, (debugfile, "Warning:User has no \".elm/elmrc\" file\n\n"));
 	} else {
